@@ -147,7 +147,6 @@ static const SeahorsePGPHeader seahorse_pgp_headers[] = {
 
 typedef struct _SeahorseAppletPrivate {
     GtkWidget           *image;
-    GtkTooltips         *tooltips;
     GtkClipboard        *board;
     GtkWidget           *menu;
     SeahorseTextType    clipboard_contents;
@@ -716,7 +715,7 @@ help_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verbname)
 	GtkWidget *dialog;
 	GError *error = NULL;
     
-	if (!gnome_url_show (document, &error)) {
+	if (!g_app_info_launch_default_for_uri (document, NULL, &error)) {
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, 
 		                                 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 		                                 _("Could not display URL: %s"),
@@ -866,13 +865,10 @@ seahorse_applet_init (SeahorseApplet *applet)
     priv->clipboard_contents = SEAHORSE_TEXT_TYPE_NONE;
     
     priv->image = gtk_image_new ();
-    priv->tooltips = gtk_tooltips_new ();
 
     gtk_container_add (GTK_CONTAINER (applet), priv->image);
 
-    g_object_ref (priv->tooltips);
-    gtk_object_sink (GTK_OBJECT (priv->tooltips));
-    gtk_tooltips_set_tip (priv->tooltips, GTK_WIDGET (applet), _("Encryption Applet"), NULL);
+    gtk_widget_set_tooltip_text (GTK_WIDGET (applet), _("Encryption Applet"));
 
     set_atk_name_description (GTK_WIDGET (applet), _("Encryption Applet"), 
                               _("Use PGP/GPG to encrypt/decrypt/sign/verify/import the clipboard."));
@@ -902,7 +898,7 @@ seahorse_applet_change_background (PanelApplet *applet, PanelAppletBackgroundTyp
     gtk_widget_set_style (GTK_WIDGET (applet), NULL);
     rc_style = gtk_rc_style_new ();
     gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-    gtk_rc_style_unref (rc_style);
+    g_object_unref (rc_style);
 
     switch (type){
     case PANEL_NO_BACKGROUND:
@@ -932,10 +928,6 @@ seahorse_applet_finalize (GObject *object)
         if (priv->menu)
             gtk_widget_destroy (priv->menu);
         priv->menu = NULL;
-        
-        if (priv->tooltips)
-            g_object_unref (G_OBJECT (priv->tooltips));
-        priv->tooltips = NULL;
     }
     
     if (G_OBJECT_CLASS (seahorse_applet_parent_class)->finalize)
