@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: seahorse-extension.c 2498 2008-09-13 22:13:48Z nnielsen $
+ *  $Id: seahorse-extension.c 2760 2009-02-04 18:19:05Z sadam $
  */
 
 #include "config.h"
@@ -246,71 +246,6 @@ notification_error (const gchar *title, const gchar *details, GError *err)
 
 }
 
-static gchar*
-lf_text (const char *text)
-{
-    gchar *utf8;
-    gunichar2 *gunc2;
-    GString *str;
-    gchar *t1, *t2, *lf;
-    glong pos;
-    gint count = 0;
-        
-    /*
-    gunc2 = (const gunichar2*) text;
-    while (gunc2[count] != 0)
-        count++;
-      
-    utf8 = g_utf16_to_utf8 (gunc2, count, NULL, NULL, NULL);
-    fprintf (stderr, "utf:\n%s\n", utf8);
-    str = g_string_new (utf8);
-    g_free (utf8);
-    */
-    str = g_string_new_len (text, g_utf8_strlen (text, strlen(text)));
-    t1 = (gchar*) str;  /* start */
-    lf = g_utf8_strchr (t1, g_utf8_strlen (t1, strlen(t1)), 0x000A); /* first line feed */
-    
-    fprintf(stderr, "text:\n%s\n", text);
-    //fprintf(stderr, "str:\n%s\n", str);
-    fprintf(stderr, "t1:\n%s\n", t1);
-    fprintf(stderr, "lf:\n%s\n", lf);
-    
-    /* skip over any short paragraphs */
-    while (lf?(g_utf8_strlen (t1, (lf - t1)) < 72) : 0) {
-        t1 = lf;
-        lf  = g_utf8_strchr (t1, g_utf8_strlen (t1, strlen(t1)), 0x000A);
-    }
-    
-    /* start looping over remaining text */
-    while ((lf ? (g_utf8_strlen (t1, g_utf8_strlen (t1, lf-t1)) > 72) : 0) ||
-           (g_utf8_strlen (t1, strlen (t1)) > 72)) {
-        /* find the first space before the 72 character/symbol */   
-        t2 = g_utf8_offset_to_pointer (t1, 72);
-        
-        while (!g_unichar_isspace (g_utf8_get_char (t2)))
-            t2 = g_utf8_find_prev_char (t1, t2);
-        
-        pos = g_utf8_pointer_to_offset((const gchar*) str, t2);      
-        str = g_string_insert_unichar (str, pos, 0x000A);
-        
-        /* reset pointers */
-        t1 = g_utf8_pointer_from_offset (str, pos + 1);
-        lf = g_utf8_strchr (t1, g_utf8_strlen (t1, strlen(t1)), 0x000A);
-        
-        /* skip over any short paragraphs */
-        while (lf ? (g_utf8_strlen (t1, (lf - t1)) < 72) : 0) {
-            t1 = lf;
-            lf  = g_utf8_strchr (t1, g_utf8_strlen (t1, strlen(t1)), 0x000A);
-        }
-    }
-    
-    t1 = g_string_free (str, FALSE);
-    utf8 = g_utf8_to_utf16 (t1, -1, NULL, NULL, NULL);
-    g_free (t1);
-    
-    return  utf8;/* return the "lf'd" string */
-}
-
 static void 
 encrypt_seahorse_cb (GtkAction *action, EphyWindow *window)
 {
@@ -320,7 +255,6 @@ encrypt_seahorse_cb (GtkAction *action, EphyWindow *window)
     gchar *signer = NULL;
     gchar *enctext = NULL;
     gboolean ret;
-    gchar *textlf, *location;
     
     init_crypt();
     
@@ -336,15 +270,6 @@ encrypt_seahorse_cb (GtkAction *action, EphyWindow *window)
 	text = mozilla_get_text (embed);
 	
 	g_return_if_fail ((text != NULL) || (text[0] != '\0'));
-	
-	location = ephy_embed_get_location (embed, TRUE);
-	if (strcasestr (location, "gmail") || strcasestr (location, "google")) {
-	    fprintf(stderr, "lf'ing text. location = %s\n", location);
-	    textlf = lf_text (text);
-    } else {
-        fprintf(stderr, "not lf'ing text.\n");
-        textlf = g_strdup (text);
-	}
     
     /* Get the recipient list */
     keys = cryptui_prompt_recipients (dbus_keyset, _("Choose Recipient Keys"), &signer);
@@ -355,14 +280,13 @@ encrypt_seahorse_cb (GtkAction *action, EphyWindow *window)
                                  G_TYPE_STRV, keys, 
                                  G_TYPE_STRING, signer, 
                                  G_TYPE_INT, 0,
-                                 G_TYPE_STRING, textlf,
+                                 G_TYPE_STRING, text,
                                  G_TYPE_INVALID,
                                  G_TYPE_STRING, &enctext,
                                  G_TYPE_INVALID);
                                 
     }
     
-    g_free (textlf);
     g_strfreev(keys);
     g_free (signer);
     
@@ -382,7 +306,6 @@ sign_seahorse_cb (GtkAction *action, EphyWindow *window)
     gchar *signer = NULL;
     gchar *enctext = NULL;
     gboolean ret;
-    gchar *textlf, *location;
     
     init_crypt();
 
@@ -399,15 +322,6 @@ sign_seahorse_cb (GtkAction *action, EphyWindow *window)
 	
 	g_return_if_fail ((text != NULL) || (text[0] != '\0'));
     
-    location = ephy_embed_get_location (embed, TRUE);
-	if (strcasestr (location, "gmail") || strcasestr (location, "google")) {
-	    fprintf(stderr, "lf'ing text. location = %s\n", location);
-	    textlf = lf_text (text);
-    } else {
-        fprintf(stderr, "not lf'ing text.\n");
-        textlf = g_strdup (text);
-	}
-	
     signer = cryptui_prompt_signer (dbus_keyset, _("Choose Key to Sign with"));
     if (signer == NULL)
         return;
@@ -416,11 +330,10 @@ sign_seahorse_cb (GtkAction *action, EphyWindow *window)
     ret = dbus_g_proxy_call (dbus_crypto_proxy, "SignText", NULL, 
                                 G_TYPE_STRING, signer, 
                                 G_TYPE_INT, 0,
-                                G_TYPE_STRING, textlf,
+                                G_TYPE_STRING, text,
                                 G_TYPE_INVALID,
                                 G_TYPE_STRING, &enctext,
                                 G_TYPE_INVALID);
-    g_free (textlf);                            
     g_free (signer);
     
     if (ret != TRUE) {
@@ -690,44 +603,22 @@ build_ui (WindowData *data)
 }
 
 
-#if EPHY_NOTAB == 1
 static void
 impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
-#else
-static void
-impl_attach_tab (EphyExtension *extension,
-		 EphyWindow *window,
-		 EphyTab *tab)
-{
-	EphyEmbed *embed;
-
-	embed = ephy_tab_get_embed (tab);
-#endif
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_connect (embed, "ge_context_menu",
 			  G_CALLBACK (context_menu_cb), window);
 }
 
-#if EPHY_NOTAB == 1
 static void
 impl_detach_tab (EphyExtension *extension,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
-#else
-static void
-impl_detach_tab (EphyExtension *extension,
-		 EphyWindow *window,
-		 EphyTab *tab)
-{
-	EphyEmbed *embed;
-
-	embed = ephy_tab_get_embed (tab);
-#endif
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_handlers_disconnect_by_func
